@@ -166,6 +166,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_apigateway
@@ -189,7 +191,7 @@ class WafwebaclToApiGateway(
         *,
         existing_api_gateway_interface: aws_cdk.aws_apigateway.IRestApi,
         existing_webacl_obj: typing.Optional[aws_cdk.aws_wafv2.CfnWebACL] = None,
-        webacl_props: typing.Optional[aws_cdk.aws_wafv2.CfnWebACLProps] = None,
+        webacl_props: typing.Optional[typing.Union[aws_cdk.aws_wafv2.CfnWebACLProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -201,6 +203,10 @@ class WafwebaclToApiGateway(
         :access: public
         :summary: Constructs a new instance of the WafwebaclToApiGateway class.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(WafwebaclToApiGateway.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = WafwebaclToApiGatewayProps(
             existing_api_gateway_interface=existing_api_gateway_interface,
             existing_webacl_obj=existing_webacl_obj,
@@ -235,7 +241,7 @@ class WafwebaclToApiGatewayProps:
         *,
         existing_api_gateway_interface: aws_cdk.aws_apigateway.IRestApi,
         existing_webacl_obj: typing.Optional[aws_cdk.aws_wafv2.CfnWebACL] = None,
-        webacl_props: typing.Optional[aws_cdk.aws_wafv2.CfnWebACLProps] = None,
+        webacl_props: typing.Optional[typing.Union[aws_cdk.aws_wafv2.CfnWebACLProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param existing_api_gateway_interface: The existing API Gateway instance that will be protected with the WAF web ACL.
@@ -246,6 +252,11 @@ class WafwebaclToApiGatewayProps:
         '''
         if isinstance(webacl_props, dict):
             webacl_props = aws_cdk.aws_wafv2.CfnWebACLProps(**webacl_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(WafwebaclToApiGatewayProps.__init__)
+            check_type(argname="argument existing_api_gateway_interface", value=existing_api_gateway_interface, expected_type=type_hints["existing_api_gateway_interface"])
+            check_type(argname="argument existing_webacl_obj", value=existing_webacl_obj, expected_type=type_hints["existing_webacl_obj"])
+            check_type(argname="argument webacl_props", value=webacl_props, expected_type=type_hints["webacl_props"])
         self._values: typing.Dict[str, typing.Any] = {
             "existing_api_gateway_interface": existing_api_gateway_interface,
         }
